@@ -2,7 +2,7 @@
 #
 #    fiksel.R
 #
-#    $Revision: 1.4 $	$Date: 2010/07/18 08:46:28 $
+#    $Revision: 1.6 $	$Date: 2012/01/18 10:13:09 $
 #
 #    Fiksel interaction 
 #    
@@ -11,18 +11,61 @@
 # -------------------------------------------------------------------
 #	
 
-Fiksel <- function(r, hc, kappa) {
-  out <- 
+Fiksel <- local({
+
+  # ......... auxiliary functions ...........
+
+  fikselterms <- function(U, X, r, kappa, EqualPairs=NULL) {
+    answer <- crossfikselterms(U, X, r, kappa)
+    nU <- npoints(U)
+    # subtract contrinbutions from identical pairs (exp(-0) = 1 for each)
+    if(!is.null(EqualPairs)) {
+      idcount <- as.integer(table(factor(EqualPairs[,2], levels=1:nU)))
+      answer <- answer - idcount
+    }
+    return(answer)
+  }
+
+  crossfikselterms <- function(X, Y, r, kappa) {
+    stopifnot(is.numeric(r))
+    # sort in increasing order of x coordinate
+    oX <- order(X$x)
+    oY <- order(Y$x)
+    Xsort <- X[oX]
+    Ysort <- Y[oY]
+    nX <- npoints(X)
+    nY <- npoints(Y)
+    # call C routine
+    out <- .C("Efiksel",
+            nnsource = as.integer(nX),
+            xsource  = as.double(Xsort$x),
+            ysource  = as.double(Xsort$y),
+            nntarget = as.integer(nY),
+            xtarget  = as.double(Ysort$x),
+            ytarget  = as.double(Ysort$y),
+            rrmax    = as.double(r),
+            kkappa   = as.double(kappa),
+            values   = as.double(double(nX)),
+            PACKAGE  = "spatstat")
+    answer <- integer(nX)
+    answer[oX] <- out$values
+    return(answer)
+  }
+
+
+  # ........ template object ..............
+  
+  BlankFiksel <- 
   list(
          name   = "Fiksel process",
          creator = "Fiksel",
-         family  = pairwise.family,
+         family  = "pairwise.family",  # evaluated later
          pot    = function(d, par) {
            v <- (d <= par$r) * exp( - d * par$kappa)
            v[ d <= par$hc ] <-  (-Inf)
            v
          },
-         par    = list(r = r, hc = hc, kappa=kappa),
+         par    = list(r = NULL, hc = NULL, kappa=NULL),  # filled in later
          parnames = c("interaction distance",
                       "hard core distance",
                       "rate parameter"), 
@@ -50,12 +93,10 @@ Fiksel <- function(r, hc, kappa) {
            return(is.finite(a))
          },
          project = function(coeffs, self) {
-           a <- (self$interpret)(coeffs, self)$param$a
-           if(is.na(a)) 
-             coeffs[1] <- 0
-           else if(!is.finite(a)) 
-             coeffs[1] <- log(.Machine$double.xmax)
-           return(coeffs)
+           if((self$valid)(coeffs, self))
+             return(NULL)
+           hc <- self$par$hc
+           if(hc > 0) return(Hardcore(hc)) else return(Poisson()) 
          },
          irange = function(self, coeffs=NA, epsilon=0, ...) {
            r <- self$par$r
@@ -68,7 +109,7 @@ Fiksel <- function(r, hc, kappa) {
            else
              return(r)
          },
-       version=versionstring.spatstat(),
+       version=NULL, # evaluated later
        # fast evaluation is available for the border correction only
        can.do.fast=function(X,correction,par) {
          return(all(correction %in% c("border", "none")))
@@ -88,44 +129,11 @@ Fiksel <- function(r, hc, kappa) {
          return(matrix(answer, ncol=1))
        }
   )
-  class(out) <- "interact"
-  (out$init)(out)
-  return(out)
-}
+  class(BlankFiksel) <- "interact"
 
-fikselterms <- function(U, X, r, kappa, EqualPairs=NULL) {
-  answer <- crossfikselterms(U, X, r, kappa)
-  nU <- npoints(U)
-  # subtract contrinbutions from identical pairs (exp(-0) = 1 for each)
-  if(!is.null(EqualPairs)) {
-    idcount <- as.integer(table(factor(EqualPairs[,2], levels=1:nU)))
-    answer <- answer - idcount
+  Fiksel <- function(r, hc, kappa) {
+    instantiate.interact(BlankFiksel, list(r = r, hc = hc, kappa=kappa))
   }
-  return(answer)
-}
 
-crossfikselterms <- function(X, Y, r, kappa) {
-  stopifnot(is.numeric(r))
-  # sort in increasing order of x coordinate
-  oX <- order(X$x)
-  oY <- order(Y$x)
-  Xsort <- X[oX]
-  Ysort <- Y[oY]
-  nX <- npoints(X)
-  nY <- npoints(Y)
-  # call C routine
-  out <- .C("Efiksel",
-            nnsource = as.integer(nX),
-            xsource  = as.double(Xsort$x),
-            ysource  = as.double(Xsort$y),
-            nntarget = as.integer(nY),
-            xtarget  = as.double(Ysort$x),
-            ytarget  = as.double(Ysort$y),
-            rrmax    = as.double(r),
-            kkappa   = as.double(kappa),
-            values   = as.double(double(nX)),
-            PACKAGE  = "spatstat")
-  answer <- integer(nX)
-  answer[oX] <- out$values
-  return(answer)
-}
+  Fiksel
+})
